@@ -3,13 +3,13 @@ use crate::date::MS_WATERSHED;
 use crate::util::timestamp_to_seconds_micros;
 use crate::{
     float_parse_bytes, numbers::decimal_digits, IntFloat, MicrosecondsPrecisionOverflowBehavior, TimeConfigBuilder,
+    TimestampUnit,
 };
 use crate::{Date, ParseError, Time, TimeConfig};
 use std::cmp::Ordering;
 use std::fmt;
 use std::str::FromStr;
 use std::time::SystemTime;
-
 /// A DateTime
 ///
 /// Combines a [Date], [Time].
@@ -26,7 +26,7 @@ use std::time::SystemTime;
 /// `DateTime` supports equality (`==`) and inequality (`>`, `<`, `>=`, `<=`) comparisons.
 ///
 /// See [DateTime::partial_cmp] for how this works.
-#[derive(Debug, PartialEq, Eq, Clone)]
+#[derive(Debug, PartialEq, Eq, Clone, Copy)]
 pub struct DateTime {
     /// date part of the datetime
     pub date: Date,
@@ -456,6 +456,50 @@ impl DateTime {
         })
     }
 
+    /// Same as `from_timestamp_with_config` where the timestamp and milliseconds
+    /// are encoded as a single float.
+    ///
+    /// # Arguments
+    ///
+    /// * `timestamp` - timestamp in either seconds or milliseconds
+    /// * `config` - the `DateTimeConfig` to use
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use speedate::{DateTime, DateTimeConfig};
+    ///
+    /// let d = DateTime::from_float_with_config(
+    ///     1_654_619_320.000123,
+    ///     &DateTimeConfig::default(),
+    /// ).unwrap();
+    /// assert_eq!(d.to_string(), "2022-06-07T16:28:40.000123");
+    ///
+    /// let d = DateTime::from_float_with_config(
+    ///     1_654_619_320_123.123,
+    ///     &DateTimeConfig::default(),
+    /// ).unwrap();
+    /// assert_eq!(d.to_string(), "2022-06-07T16:28:40.123123");
+    /// ```
+    pub fn from_float_with_config(timestamp: f64, mode: &DateTimeConfig) -> Result<Self, ParseError> {
+        let microseconds = match mode.timestamp_unit {
+            TimestampUnit::Second => timestamp.fract().abs() * 1_000_000.0,
+            TimestampUnit::Millisecond => timestamp.fract().abs() * 1_000.0,
+            TimestampUnit::Infer => {
+                if timestamp.abs() <= MS_WATERSHED as f64 {
+                    // treat as seconds
+                    timestamp.fract().abs() * 1_000_000.0
+                } else {
+                    // treat as milliseconds
+                    timestamp.fract().abs() * 1_000.0
+                }
+            }
+        };
+        // checking for extra digits in microseconds is unreliable with large floats,
+        // so we just round to the nearest microsecond
+        Self::from_timestamp_with_config(timestamp.floor() as i64, microseconds.round() as u32, mode)
+    }
+
     /// Create a datetime from a Unix Timestamp in seconds or milliseconds
     ///
     /// ("Unix Timestamp" means number of seconds or milliseconds since 1970-01-01)
@@ -545,7 +589,7 @@ impl DateTime {
     /// ```
     pub fn with_timezone_offset(&self, tz_offset: Option<i32>) -> Result<Self, ParseError> {
         Ok(Self {
-            date: self.date.clone(),
+            date: self.date,
             time: self.time.with_timezone_offset(tz_offset)?,
         })
     }
